PreviewResponse

Struct PreviewResponse 

pub struct PreviewResponse {
    pub path: PathBuf,
    pub tab_index: usize,
    pub line_nr: Option<usize>,
    pub preview: Preview,
}
Response from the preview builder with the request data it came from. The path and tab index are used to ensure we’re attaching the correct preview for this tab, The line number, if any, is used to scroll the the line. Only fuzzy picker of line may output a line number.

Fields

path: PathBuftab_index: usizeline_nr: Option<usize>preview: Preview