pub enum ActionMap {
Show 102 variants
Action,
Back,
Backspace,
Bulk,
Cd,
Chmod,
ClearFlags,
CliMenu,
CloudDrive,
Compress,
Context,
CopyContent,
CopyFilename,
CopyFilepath,
CopyPaste,
Cursor,
CutPaste,
Delete,
DeleteLeft,
DeleteLine,
DisplayFlagged,
End,
Enter,
Exec,
Filter,
FlagAll,
FlaggedToClipboard,
FlaggedFromClipboard,
FocusGoLeft,
FocusGoRight,
FocusGoDown,
FocusGoUp,
FuzzyFind,
FuzzyFindHelp,
FuzzyFindLine,
GoRoot,
GoStart,
Help,
History,
Home,
KeyHome,
Log,
MarksJump,
MarksNew,
MoveDown,
MoveLeft,
MoveRight,
MoveUp,
Mount,
NextThing,
NextWord,
NewDir,
NewFile,
Nothing,
NvimFilepicker,
NvimSetAddress,
OpenConfig,
OpenFile,
OpenAll,
PageDown,
PageUp,
Preview,
PreviousThing,
PreviousWord,
Quit,
RefreshIfNeeded,
RefreshView,
RegexMatch,
RemoteMount,
Rename,
ResetMode,
ReverseFlags,
Search,
SearchNext,
Shell,
ShellCommand,
TempMarksJump,
TempMarksNew,
TuiMenu,
Shortcut,
Sort,
Symlink,
SyncLTR,
Tab,
ToggleDisplayFull,
ToggleDualPane,
ToggleFlag,
ToggleFlagChildren,
ToggleHidden,
TogglePreviewSecond,
TrashEmpty,
TrashMoveFile,
TrashOpen,
TrashRestoreFile,
Tree,
TreeDepthDecr,
TreeDepthIncr,
TreeFold,
TreeFoldAll,
TreeUnFoldAll,
ToggleVisual,
Custom(String),
}Expand description
Different kind of action which can be mapped to a key. All those actions are mapped to a key and this enum makes the junction between received Key events and actions in the application.
Variants
Action
Back
Backspace
Bulk
Cd
Chmod
ClearFlags
CliMenu
CloudDrive
Compress
Context
CopyContent
CopyFilename
CopyFilepath
CopyPaste
Cursor
CutPaste
Delete
DeleteLeft
DeleteLine
DisplayFlagged
End
Enter
Exec
Filter
FlagAll
FlaggedToClipboard
FlaggedFromClipboard
FocusGoLeft
FocusGoRight
FocusGoDown
FocusGoUp
FuzzyFind
FuzzyFindHelp
FuzzyFindLine
GoRoot
GoStart
Help
History
Home
KeyHome
Log
MarksJump
MarksNew
MoveDown
MoveLeft
MoveRight
MoveUp
Mount
NextThing
NextWord
NewDir
NewFile
Nothing
NvimFilepicker
NvimSetAddress
OpenConfig
OpenFile
OpenAll
PageDown
PageUp
Preview
PreviousThing
PreviousWord
Quit
RefreshIfNeeded
RefreshView
RegexMatch
RemoteMount
Rename
ResetMode
ReverseFlags
Search
SearchNext
Shell
ShellCommand
TempMarksJump
TempMarksNew
TuiMenu
Shortcut
Sort
Symlink
SyncLTR
Tab
ToggleDisplayFull
ToggleDualPane
ToggleFlag
ToggleFlagChildren
ToggleHidden
TogglePreviewSecond
TrashEmpty
TrashMoveFile
TrashOpen
TrashRestoreFile
Tree
TreeDepthDecr
TreeDepthIncr
TreeFold
TreeFoldAll
TreeUnFoldAll
ToggleVisual
Custom(String)
Implementations