create_stream

Function create_stream 

pub fn create_stream() -> Result<(String, UnixListener)>
Creates UNIX socket stream used by the application If the user provided an input socket from args, it will use it. Otherwise, it will use “/tmp/fm-socket-{pid}.sock” where pid is the process identifier of the application itself. Read timeout is set to 1_000_000 ns = 0.001 s Returns the pair “file_path, stream”