pub struct EventReader {
pub fm_receiver: Receiver<FmEvents>,
pub socket_path: String,
pub socket_listener: UnixListener,
}Expand description
Simple struct to read the events.
Fields
fm_receiver: Receiver<FmEvents>socket_path: Stringsocket_listener: UnixListenerImplementations
Sourceimpl EventReader
impl EventReader
Sourcepub fn new(fm_receiver: Receiver<FmEvents>) -> Self
pub fn new(fm_receiver: Receiver<FmEvents>) -> Self
Creates a new instance with an Arc to a terminal.
Sourcepub fn poll_event(&self) -> FmEvents
pub fn poll_event(&self) -> FmEvents
Returns the events as they’re received. Loops until an event is received. We should spend most of the application life here, polling for next event :)
It’s an interface for internal and extenal events (through terminal)
casting them into an crate::event::FmEvents.