list_plugins

Function list_plugins 

pub fn list_plugins()
List all installed plugins referenced in [crate::common::CONFIG_PATH] It will print a list of status, plugin name and libso paths to stdout.

status can either be:

  • ok if the libso file exists or
  • ?? if it doesn’t.

Warning

It doesn’t check if the plugin works, only the existence of its libso file.

Error

It may fail if the config file isn’t formated properly.