Cursor

Struct Cursor 

pub struct Cursor {
    pub is_dragging: bool,
    pub leave_bind: String,
    pub enter_bind: String,
    pub copy_bind: String,
    /* private fields */
}
Cursor is used to select and copy or log text directly from fm output. Once the cursor is active, you can’t move in the file tree or open menus etc. You can only :

  • toggle the selection state,
  • move the cursor with keys or mouse,
  • copy the selected chars (only while selecting)
  • leave the cursor and go back to normal usage of fm,
  • exit fm completely

It’s a way to allow copying text without having to exit fm or open a new shell.

Cursor has a state (inactive, movement, selecting), knows its position and where it started its selection. We also store the associated binds to help the user.

Fields

is_dragging: bool

Are we dragging the cursor with the mouse ?

leave_bind: String

What is the keybind associated to leave menu ?

enter_bind: String

What is the keybind associated to entering the cursor ? It’s used to toggle selection state.

copy_bind: String

What is the bind associated to copy/paste. Used to copy the selection to clipboard and log it.

Implementations

Source

impl Cursor

pub fn new(binds: &Bindings) -> Self

Creates a new cursor with binds read from keybinds.

pub fn rect(&self) -> Option<Rect>

Copy of the inner rect.

pub fn cursor(&self) -> Option<Position>

Position of the cursor if any

pub fn is_active(&self) -> bool

True iff the cursor is in active mode (either movement or selecting)

pub fn is_selecting(&self) -> bool

True iff the cursor is selecting.

pub fn reset(&mut self)

Reset the cursor. set state to inactive, erase cusrsor, origin & rect and set is_dragging to false.

pub fn toggle(&mut self, position: Position)

Set the state from inactive to movement or toggle between movement & selecting.

pub fn move_cursor(&mut self, direction: CursorDirection, _: Size)

Move the cursor in given direction. Cursor is clamped to the the screen. It’s coordinates can’t be equal or bigger to terminal height or width.

pub fn move_cursor_to(&mut self, position: Position)

Move the cursor to position Does nothing if cursor isn’t active.

pub fn move_origin_to(&mut self, position: Position)

Move the origin of selection to position Does nothing if cursor isn’t active.

pub fn extend_selection(&mut self)

Update the selection from origin to current position. Does nothing if cursor isn’t active.

pub fn mouse_drag(&mut self, row: u16, col: u16)

Used to allow selecting text with the mouse. Either start selecting from previous position if we enter the “dragging” state Move the cursor to the current mouse position. Or extend selection.

pub fn stop_drag(&mut self)

Stop dragging.