pub enum Navigate {
Show 13 variants
History,
Shortcut,
Trash,
Marks(MarkAction),
TempMarks(MarkAction),
Mount,
Compress,
TuiApplication,
CliApplication,
Context,
Cloud,
Picker,
Flagged,
}Expand description
Different modes in which we display a bunch of possible actions. In all those mode we can select an action and execute it. For some of them, it’s just moving there, for some it acts on some file.
Variants
History
Navigate back to a visited path
Shortcut
Navigate to a predefined shortcut
Trash
Manipulate trash files
Marks(MarkAction)
Edit a mark or cd to it
TempMarks(MarkAction)
Edit a temporary mark or cd to it
Mount
See mount points, mount, unmount partions
Compress
Pick a compression method
TuiApplication
Shell menu applications. Start a new shell with this application.
CliApplication
Cli info
Context
Context menu
Cloud
Cloud menu
Picker
Picker menu
Flagged
Flagged files
Implementations
True if the draw_menu trait can be called directly to display this mode