pub struct CaseDependantRegex { /* private fields */ }Expand description
Case dependant regular expression.
It holds an input string (the original regular expression) and a regular expression.
If the input string contains an uppercase character, we use it as is.
If not, we make the regular expression case insensitive by adding (?i) in front of it.
If the input is “Car” it will match against “Car”, “Cargo” but not “car”. If the input is “car” it will match against “Car”, “Cargo” and “car”.
This is inspired by ranger which take it from vim/neovim.
Implementations