pub struct Completion {
pub content: Vec<String>,
pub index: usize,
}Expand description
Holds a Vec<String> of possible completions and an usize index
showing where the user is in the vec.
Fields
content: Vec<String>Possible completions
index: usizeWhich completion is selected by the user
Implementations
Sourceimpl Completion
impl Completion
Sourcepub fn current_proposition(&self) -> &str
pub fn current_proposition(&self) -> &str
Returns the currently selected proposition.
Returns an empty string if proposals is empty.
Sourcepub fn cd(&mut self, current_path: &str, input_string: &str)
pub fn cd(&mut self, current_path: &str, input_string: &str)
Cd completion. Looks for the valid path completing what the user typed.
Sourcepub fn exec(&mut self, input_string: &str)
pub fn exec(&mut self, input_string: &str)
Looks for programs in $PATH completing the one typed by the user.
Sourcepub fn action(&mut self, input_string: &str)
pub fn action(&mut self, input_string: &str)
Looks for fm actions completing the one typed by the user.
Sourcepub fn search(&mut self, files: Vec<String>)
pub fn search(&mut self, files: Vec<String>)
Looks for file within current folder completing what the user typed.
Sourcepub fn complete_input_string(&self, input_string: &str) -> Option<&str>
pub fn complete_input_string(&self, input_string: &str) -> Option<&str>
Complete the input string with current_proposition if possible. Returns the optional last chars of the current_proposition. If the current_proposition doesn’t start with input_string, it returns None.