pub struct DisplayedImage {
pub kind: Kind,
pub identifier: String,
pub images: Vec<PathBuf>,
pub index: usize,
/* private fields */
}Expand description
Holds the informations about the displayed image.
it’s used to display the image itself, calling draw with parameters for its position and dimension.
Fields
kind: Kindidentifier: Stringimages: Vec<PathBuf>index: usizeImplementations
Sourceimpl DisplayedImage
impl DisplayedImage
pub fn filepath(&self) -> Arc<Path>
Sourcepub fn up_one_row(&mut self)
pub fn up_one_row(&mut self)
Only affect pdf thumbnail. Will decrease the index if possible.
Sourcepub fn down_one_row(&mut self)
pub fn down_one_row(&mut self)
Only affect pdf thumbnail. Will increase the index if possible.
pub fn is_empty(&self) -> bool
Sourcepub fn selected_path(&self) -> Cow<'_, str>
pub fn selected_path(&self) -> Cow<'_, str>
Path of the currently selected image as a COW &str.