pub struct IsoDevice {
pub path: String,
pub mountpoints: Option<String>,
/* private fields */
}Expand description
Used to mount an iso file as a loop device.
Holds info about its source (path) and optional mountpoint (mountpoints).
Since it’s used once and nothing can be done with it after mounting, it’s dropped as soon as possible.
Fields
path: StringThe source, aka the iso file itself.
mountpoints: Option<String>None when creating, updated once the device is mounted.
Implementations