pub struct Marks {
pub index: usize,
/* private fields */
}Expand description
Holds the marks created by the user.
It’s an ordered map between any char (except :, and control char) and a PathBuf.
Fields
index: usizeImplementations
Sourceimpl Marks
impl Marks
Sourcepub fn setup(&mut self)
pub fn setup(&mut self)
Reads the marks stored in the config file (~/.config/fm/marks.cfg). If an invalid marks is read, only the valid ones are kept and the file is saved again.
Sourcepub fn get(&self, key: char) -> Option<PathBuf>
pub fn get(&self, key: char) -> Option<PathBuf>
Returns an optional marks associated to a char bind.
Sourcepub fn new_mark(&mut self, ch: char, path: &Path) -> Result<()>
pub fn new_mark(&mut self, ch: char, path: &Path) -> Result<()>
Store a new mark in the config file. If an update is done, the marks are saved again.
Errors
It may fail if writing to the marks file fails.
pub fn remove_selected(&mut self) -> Result<()>
Sourcepub fn as_strings(&self) -> Vec<String>
pub fn as_strings(&self) -> Vec<String>
Returns a vector of strings like “d: /dev” for every mark.
Sourcepub fn char_for(&self, path: &Path) -> &char
pub fn char_for(&self, path: &Path) -> &char
Returns the char for associated to a path. For marked path, it’s their mark, Otherwise it’s ’ ’
Sourcepub fn move_path(&mut self, old_path: &Path, new_path: &Path) -> Result<()>
pub fn move_path(&mut self, old_path: &Path, new_path: &Path) -> Result<()>
Change mark path from old_path to new_path and write the marks to disk
Sourcepub fn remove_path(&mut self, old_path: &Path) -> Result<()>
pub fn remove_path(&mut self, old_path: &Path) -> Result<()>
Remove a path from marks. Does nothing if the path isn’t marked. If the path is marked, it’s removed everywhere (paths_to_mark, content and used_ch). The marks are then saved.