pub struct SortKind { /* private fields */ }Expand description
Describe a way of sorting
Implementations
Sourceimpl SortKind
impl SortKind
Sourcepub const fn tree_default() -> Self
pub const fn tree_default() -> Self
Default kind of sort for a tree view. Since files are in reverse order, we need to sort in descending order.
Sourcepub fn update_from_char(&mut self, c: char)
pub fn update_from_char(&mut self, c: char)
Updates itself from a given character. If the character describes a kind of sort, we apply it. (k n m s e – K N M S E) If the character is lowercase, we sort by Ascending order, else Descending order. If the character is ‘r’ or ‘R’ we reverse current kind of sort.