pub struct TempMarks {
pub index: usize,
/* private fields */
}Expand description
Temporary marks are saved in memory and reset when the application quit.
We save a fixed size vector of pathbufs. The user can set a mark (default bind alt+“) and jump to it (default bind “).
Fields
index: usizeImplementations
Sourceimpl TempMarks
impl TempMarks
Sourcepub fn set_mark(&mut self, index: usize, path: PathBuf)
pub fn set_mark(&mut self, index: usize, path: PathBuf)
Set the mark at given index to the given path.
Sourcepub fn erase_current_mark(&mut self)
pub fn erase_current_mark(&mut self)
Reset the selected mark to None
Sourcepub fn get_mark(&self, index: usize) -> &Option<PathBuf>
pub fn get_mark(&self, index: usize) -> &Option<PathBuf>
Get the indexed mark. None if the mark isn’t set.
Render the marks on the screen.
Can’t use the common trait nor the macro since Option<PathBuf> doesn’t implement CowStr.
pub fn digit_for(&self, path: &Path) -> Option<usize>
Sourcepub fn move_path(&mut self, old_path: &Path, new_path: &Path)
pub fn move_path(&mut self, old_path: &Path, new_path: &Path)
Update the temp mark associated to old_path.
Does nothing if old_path isn’t associated to a temp mark.
Sourcepub fn remove_path(&mut self, old_path: &Path)
pub fn remove_path(&mut self, old_path: &Path)
Reset the temp mark associated to old_path.
Does nothing if no mark is set for old_path.