JoinQuote

Trait JoinQuote 

pub trait JoinQuote {
    // Required method
    fn join_quote(&self, sep: &str) -> String;
}
Used to shell quote every filepath of a vector of string.

Required Methods

fn join_quote(&self, sep: &str) -> String

Implementations on Foreign Types

Source

impl JoinQuote for &Vec<String>

Source

fn join_quote(&self, sep: &str) -> String

Quote every filepath in the vector and join them.

Implementors