pub trait JoinQuote {
// Required method
fn join_quote(&self, sep: &str) -> String;
}Expand description
Used to shell quote every filepath of a vector of string.
Required Methods
fn join_quote(&self, sep: &str) -> String
Implementations on Foreign Types
Sourceimpl JoinQuote for &Vec<String>
impl JoinQuote for &Vec<String>
Sourcefn join_quote(&self, sep: &str) -> String
fn join_quote(&self, sep: &str) -> String
Quote every filepath in the vector and join them.